==> unit-1.0.25-sources.jar: io/intino/goros/unit/box/ui/displays/templates/AbstractNodeLinksOutTemplate.java <==
package io.intino.goros.unit.box.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractNodeLinksOutTemplate<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, java.lang.Void, B> {
	public LinksOutTable linksOutTable;
	public NodeLinksOutTemplate.LinksOutTable. LinksOutTableLabelHeading linksOutTableLabelHeading;
	public NodeLinksOutTemplate.LinksOutTable.LinksOutTableLabelHeading. _22_39_11182118849 _22_39_11182118849;
	public NodeLinksOutTemplate.LinksOutTable. LinksOutTableDescriptionHeading linksOutTableDescriptionHeading;
	public NodeLinksOutTemplate.LinksOutTable.LinksOutTableDescriptionHeading. _25_45_11718484075 _25_45_11718484075;

    public AbstractNodeLinksOutTemplate(B box) {
        super(box);
        id("nodeLinksOutTemplate");
    }

    @Override
	public void init() {
		super.init();
		if (linksOutTable == null) linksOutTable = register(new LinksOutTable(box()).<LinksOutTable>id("a_1667404950").owner(AbstractNodeLinksOutTemplate.this));
		if (linksOutTable != null) linksOutTableLabelHeading = linksOutTable.linksOutTableLabelHeading;
		if (linksOutTableLabelHeading != null) _22_39_11182118849 = linksOutTable.linksOutTableLabelHeading._22_39_11182118849;
		if (linksOutTable != null) linksOutTableDescriptionHeading = linksOutTable.linksOutTableDescriptionHeading;
		if (linksOutTableDescriptionHeading != null) _25_45_11718484075 = linksOutTable.linksOutTableDescriptionHeading._25_45_11718484075;
	}

	public class LinksOutTable extends io.intino.alexandria.ui.displays.components.Table<B, io.intino.alexandria.ui.displays.components.Row, org.monet.space.kernel.model.Node>  {
		public NodeLinksOutTemplate.LinksOutTable. LinksOutTableLabelHeading linksOutTableLabelHeading;
		public NodeLinksOutTemplate.LinksOutTable. LinksOutTableDescriptionHeading linksOutTableDescriptionHeading;

		public LinksOutTable(B box) {
			super(box);

			_pageSize(20);
		}

		@Override
		public void init() {
			super.init();
			if (linksOutTableLabelHeading == null) linksOutTableLabelHeading = register(new LinksOutTableLabelHeading(box()).<LinksOutTableLabelHeading>id("a_799515539").owner(AbstractNodeLinksOutTemplate.this));
			if (linksOutTableDescriptionHeading == null) linksOutTableDescriptionHeading = register(new LinksOutTableDescriptionHeading(box()).<LinksOutTableDescriptionHeading>id("a8808").owner(AbstractNodeLinksOutTemplate.this));
		}


		public LinksOutTableRow create(org.monet.space.kernel.model.Node item) {
			LinksOutTableRow row = new LinksOutTableRow((UnitBox)box());
			row.id(java.util.UUID.randomUUID().toString());
			row.item(item);
			return row;
		}
		public class LinksOutTableLabelHeading extends io.intino.alexandria.ui.displays.components.Heading<io.intino.alexandria.ui.displays.notifiers.HeadingNotifier, B>  {
			public NodeLinksOutTemplate.LinksOutTable.LinksOutTableLabelHeading. _22_39_11182118849 _22_39_11182118849;

			public LinksOutTableLabelHeading(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (_22_39_11182118849 == null) _22_39_11182118849 = register(new _22_39_11182118849(box()).<_22_39_11182118849>id("a317225545").owner(AbstractNodeLinksOutTemplate.this));
			}

			public class _22_39_11182118849 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

				public _22_39_11182118849(B box) {
					super(box);
					_value("Título");
				}

				@Override
				public void init() {
					super.init();
				}
			}
		}

		public class LinksOutTableDescriptionHeading extends io.intino.alexandria.ui.displays.components.Heading<io.intino.alexandria.ui.displays.notifiers.HeadingNotifier, B>  {
			public NodeLinksOutTemplate.LinksOutTable.LinksOutTableDescriptionHeading. _25_45_11718484075 _25_45_11718484075;

			public LinksOutTableDescriptionHeading(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (_25_45_11718484075 == null) _25_45_11718484075 = register(new _25_45_11718484075(box()).<_25_45_11718484075>id("a_1285287854").owner(AbstractNodeLinksOutTemplate.this));
			}

			public class _25_45_11718484075 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

				public _25_45_11718484075(B box) {
					super(box);
					_value("Descripción");
				}

				@Override
				public void init() {
					super.init();
				}
			}
		}
	}
}

==> unit-1.1.1-sources.jar: io/intino/goros/unit/box/ui/displays/templates/AbstractNodeLinksOutTemplate.java <==
package io.intino.goros.unit.box.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractNodeLinksOutTemplate<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, java.lang.Void, B> {
	public LinksOutTable linksOutTable;
	public NodeLinksOutTemplate.LinksOutTable. LinksOutTableLabelHeading linksOutTableLabelHeading;
	public NodeLinksOutTemplate.LinksOutTable.LinksOutTableLabelHeading. _22_39_11182118849 _22_39_11182118849;
	public NodeLinksOutTemplate.LinksOutTable. LinksOutTableDescriptionHeading linksOutTableDescriptionHeading;
	public NodeLinksOutTemplate.LinksOutTable.LinksOutTableDescriptionHeading. _25_45_11718484075 _25_45_11718484075;

    public AbstractNodeLinksOutTemplate(B box) {
        super(box);
        id("nodeLinksOutTemplate");
    }

    @Override
	public void init() {
		super.init();
		if (linksOutTable == null) linksOutTable = register(new LinksOutTable(box()).<LinksOutTable>id("a_1667404950").owner(AbstractNodeLinksOutTemplate.this));
		if (linksOutTable != null) linksOutTableLabelHeading = linksOutTable.linksOutTableLabelHeading;
		if (linksOutTableLabelHeading != null) _22_39_11182118849 = linksOutTable.linksOutTableLabelHeading._22_39_11182118849;
		if (linksOutTable != null) linksOutTableDescriptionHeading = linksOutTable.linksOutTableDescriptionHeading;
		if (linksOutTableDescriptionHeading != null) _25_45_11718484075 = linksOutTable.linksOutTableDescriptionHeading._25_45_11718484075;
	}

    @Override
    public void remove() {
        super.remove();
	    if (linksOutTable != null) linksOutTable.unregister();
	}

	public class LinksOutTable extends io.intino.alexandria.ui.displays.components.Table<B, io.intino.alexandria.ui.displays.components.Row, org.monet.space.kernel.model.Node>  {
		public NodeLinksOutTemplate.LinksOutTable. LinksOutTableLabelHeading linksOutTableLabelHeading;
		public NodeLinksOutTemplate.LinksOutTable. LinksOutTableDescriptionHeading linksOutTableDescriptionHeading;

		public LinksOutTable(B box) {
			super(box);

			_pageSize(20);
		}

		@Override
		public void init() {
			super.init();
			if (linksOutTableLabelHeading == null) linksOutTableLabelHeading = register(new LinksOutTableLabelHeading(box()).<LinksOutTableLabelHeading>id("a_799515539").owner(AbstractNodeLinksOutTemplate.this));
			if (linksOutTableDescriptionHeading == null) linksOutTableDescriptionHeading = register(new LinksOutTableDescriptionHeading(box()).<LinksOutTableDescriptionHeading>id("a8808").owner(AbstractNodeLinksOutTemplate.this));
		}

		@Override
		public void unregister() {
		    super.unregister();
			if (linksOutTableLabelHeading != null) linksOutTableLabelHeading.unregister();
			if (linksOutTableDescriptionHeading != null) linksOutTableDescriptionHeading.unregister();
		}


		public LinksOutTableRow create(org.monet.space.kernel.model.Node item) {
			LinksOutTableRow row = new LinksOutTableRow((UnitBox)box());
			row.id(java.util.UUID.randomUUID().toString());
			row.item(item);
			return row;
		}
		public class LinksOutTableLabelHeading extends io.intino.alexandria.ui.displays.components.Heading<io.intino.alexandria.ui.displays.notifiers.HeadingNotifier, B>  {
			public NodeLinksOutTemplate.LinksOutTable.LinksOutTableLabelHeading. _22_39_11182118849 _22_39_11182118849;

			public LinksOutTableLabelHeading(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (_22_39_11182118849 == null) _22_39_11182118849 = register(new _22_39_11182118849(box()).<_22_39_11182118849>id("a317225545").owner(AbstractNodeLinksOutTemplate.this));
			}

			@Override
			public void unregister() {
			    super.unregister();
				if (_22_39_11182118849 != null) _22_39_11182118849.unregister();
			}

			public class _22_39_11182118849 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

				public _22_39_11182118849(B box) {
					super(box);
					_value("Título");
				}

				@Override
				public void init() {
					super.init();
				}

				@Override
				public void unregister() {
				    super.unregister();
				}
			}
		}

		public class LinksOutTableDescriptionHeading extends io.intino.alexandria.ui.displays.components.Heading<io.intino.alexandria.ui.displays.notifiers.HeadingNotifier, B>  {
			public NodeLinksOutTemplate.LinksOutTable.LinksOutTableDescriptionHeading. _25_45_11718484075 _25_45_11718484075;

			public LinksOutTableDescriptionHeading(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (_25_45_11718484075 == null) _25_45_11718484075 = register(new _25_45_11718484075(box()).<_25_45_11718484075>id("a_1285287854").owner(AbstractNodeLinksOutTemplate.this));
			}

			@Override
			public void unregister() {
			    super.unregister();
				if (_25_45_11718484075 != null) _25_45_11718484075.unregister();
			}

			public class _25_45_11718484075 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

				public _25_45_11718484075(B box) {
					super(box);
					_value("Descripción");
				}

				@Override
				public void init() {
					super.init();
				}

				@Override
				public void unregister() {
				    super.unregister();
				}
			}
		}
	}
}
